unofficial mirror of guix-patches@gnu.org 
 help / color / mirror / code / Atom feed
From: "Ludovic Courtès" <ludo@gnu.org>
To: 62183@debbugs.gnu.org
Cc: "Ludovic Courtès" <ludovic.courtes@inria.fr>
Subject: [bug#62183] [PATCH v2 1/2] gnu: vtk: Enable OpenMP, TBB, and Open MPI support.
Date: Mon, 20 Mar 2023 23:09:55 +0100	[thread overview]
Message-ID: <20230320220956.13920-1-ludo@gnu.org> (raw)
In-Reply-To: <20230314110422.8667-1-ludo@gnu.org>

From: Ludovic Courtès <ludovic.courtes@inria.fr>

* gnu/packages/image-processing.scm (vtk)[arguments]: Pass options to
enable OpenMP, TBB, and MPI.
[inputs]: Add OPENMPI.
[propagated-inputs]: Add TBB.
---
 gnu/packages/image-processing.scm | 15 +++++++++++----
 1 file changed, 11 insertions(+), 4 deletions(-)

Change since v1: TBB is now propagated, fixing builds of mia and f3d.

Ludo'.

diff --git a/gnu/packages/image-processing.scm b/gnu/packages/image-processing.scm
index 0562376291..c8786d8edd 100644
--- a/gnu/packages/image-processing.scm
+++ b/gnu/packages/image-processing.scm
@@ -1,7 +1,7 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2017 John Darrington <jmd@gnu.org>
 ;;; Copyright © 2017, 2019, 2022 Ricardo Wurmus <rekado@elephly.net>
-;;; Copyright © 2014, 2021-2022 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2014, 2021-2023 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright © 2014 Mark H Weaver <mhw@netris.org>
 ;;; Copyright © 2016 Eric Bavier <bavier@member.fsf.org>
 ;;; Copyright © 2018–2021 Tobias Geerinckx-Rice <me@tobias.gr>
@@ -380,6 +380,10 @@ (define-public vtk
                            "-DVTK_MODULE_ENABLE_VTK_RenderingExternal=YES" ; For F3D
                            "-DVTK_WRAP_PYTHON=ON"
                            "-DVTK_PYTHON_VERSION:STRING=3"
+
+                           "-DVTK_SMP_ENABLE_OPENNMP=ON"
+                           "-DVTK_SMP_ENABLE_TBB=ON"
+                           "-DVTK_USE_MPI=ON"
                            )
        #:tests? #f))        ;XXX: test data not included
     (inputs
@@ -402,17 +406,20 @@ (define-public vtk
            mesa
            netcdf
            libpng
+           libtiff
+           openmpi
            proj-7
            python
            ;("pugixml" ,pugixml)
            sqlite
-           libtiff
            xorgproto
            zlib))
     (propagated-inputs
      ;; VTK's 'VTK-vtk-module-find-packages.cmake' calls
-     ;; 'find_package(THEORA)', which in turns looks for libogg.
-     (list libogg))
+     ;; 'find_package(THEORA)', which in turns looks for libogg.  Likewise for
+     ;; TBB.
+     (list libogg
+           tbb))
     (home-page "https://vtk.org/")
     (synopsis "Libraries for 3D computer graphics")
     (description

base-commit: 99114eb63895712d2d3e62c5a83e3a1540438f15
-- 
2.39.2





  parent reply	other threads:[~2023-03-20 22:11 UTC|newest]

Thread overview: 8+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-03-14 11:04 [bug#62183] [PATCH 0/2] VTK packaging improvements for HPC Ludovic Courtès
2023-03-14 11:06 ` [bug#62183] [PATCH 1/2] gnu: vtk: Enable OpenMP, TBB, and Open MPI support Ludovic Courtès
2023-03-14 11:06   ` [bug#62183] [PATCH 2/2] gnu: vtk: Remove reference to GCC Ludovic Courtès
2023-03-20 22:09 ` Ludovic Courtès [this message]
2023-03-20 22:09   ` [bug#62183] [PATCH v2 " Ludovic Courtès
2023-03-21 18:12     ` bug#62183: [PATCH 0/2] VTK packaging improvements for HPC Ludovic Courtès
2023-04-07 15:38     ` [bug#62183] [PATCH v2 2/2] gnu: vtk: Remove reference to GCC Simon Tournier
2023-04-17  8:17       ` Ludovic Courtès

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: https://guix.gnu.org/

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20230320220956.13920-1-ludo@gnu.org \
    --to=ludo@gnu.org \
    --cc=62183@debbugs.gnu.org \
    --cc=ludovic.courtes@inria.fr \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/guix.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).